@@ -1,7 +1,7 @@
 import requests
 from typing import Tuple, Optional
 
-from src.notifier_client.utils import GlobalVariables, send_alert, send_message
+from notifier_client.utils import GlobalVariables, send_alert, send_message
 
 
 class WebAppNotifierClient:
